@@ -1,14 +1,13 @@
 package scriptname;
-# ABSTRACT: Locate original perl script
 
 use strict;
 use warnings;
-use 5.000;
+use 5.008;
 
 my($myname, $mybase, $mydir);
 
 BEGIN {
-  our $VERSION = '0.11';
+  use version; our $VERSION = qv('0.3');
   our $AUTHORITY = 'MASSA';
 
   use Carp;
@@ -30,10 +29,10 @@ BEGIN {
   our %EXPORT_TAGS = (all => [@EXPORT_OK]);
 }
 
-sub myname() { $myname } ## no critic
-sub mybase() { $mybase } ## no critic
-sub mydir()  { $mydir  } ## no critic
-sub _mylib   { map realpath("$mydir/$_"), (@_ ? @_ : qw(./lib)) }
+sub myname() { $myname }
+sub mybase() { $mybase }
+sub mydir()  { $mydir  }
+sub _mylib   { map realpath("$mydir/$_"), @_ }
 
 sub import {
   my $package = shift;
@@ -51,19 +50,19 @@ sub unimport {
 }
 
 # Magic true value required at end of module
-1;
-
+1
 
 __END__
-=pod
 
 =head1 NAME
 
 scriptname - Locate original perl script
 
+
 =head1 VERSION
 
-version 0.11
+This document describes scriptname version 0.3
+
 
 =head1 SYNOPSIS
 
@@ -83,15 +82,7 @@ you can also use
 
     no scriptname lib => '../lib';
 
-to remove a relative path from C<@INC>. As a special case,
-
-    use scriptname 'lib';
-
-is equivalent to
-
-    use scriptname lib => 'lib';
-
-(unshift the path to the current script + 'lib' in @INC)
+to unload a relative lib from the @INC path.
 
 =head1 DESCRIPTION
 
@@ -102,33 +93,34 @@ paths relative to the script's directory in @INC.
 This allows a user to setup a directory tree for some software with
 directories C<< <root>/bin >> and C<< <root>/lib >>, and then the above
 example will allow the use of modules in the lib directory without knowing
-where the software tree is installed, even if the name by which the script
-was called is a symbolic link to the path where the C<../bin> and the
-C<../lib> actually are.
+where the software tree is installed.
 
 If perl is invoked using the B<-e> option or the perl script is read from
 C<STDIN> then the module sets C<mydir> to the current working
 directory.
 
-=head1 FUNCTIONS
+=head1 EXPORTABLE FUNCTIONS
 
-=head2 myname
+=over
+
+=item C<< myname >>
 
 fully qualified path for the script (with all links resolved), undef if called
 from C<-e> or C<STDIN>
 
-=head2 mybase
+=item C<< mybase >>
 
 basename of C<myname>, or undef
 
-=head2 mydir
+=item C<< mydir >>
 
 dirname of C<myname>, or the current working directory if called from C<-e> or C<STDIN>
 
-=head2 $0
+=back
 
 The result of C<myname> is also put in C<$0> unless called from C<-e> or C<STDIN>.
 
+
 =head1 DIAGNOSTICS
 
 =over
@@ -159,67 +151,7 @@ Also depends on C<version>.
 
 =head1 INCOMPATIBILITIES
 
-=head2 Differences from C<< FindBin >>
-
-C<scriptname> does not search B<PATH>. It makes one of the following assumptions:
-
-=over
-
-=item C<$0> comes with an absolute filename (starting from root)
-
-This can happen:
-
-=over
-
-=item *
-
-When the script was called with B<perl -S> -- in this case, perl looked the B<PATH> for the script;
-
-=item *
-
-When the script was called with B<perl> I<absolute_file_name>;
-
-=item *
-
-When the script was called by the shebang and the shell/kernel (whoever
-interpreted the shebang) was passed pathless command name -- 
-when the shell/kernel searched the B<PATH> and found the file,
-it passes the absolute filename to B<perl>;
-
-=item *
-
-When the script was called by the shebang and the shell/kernel was
-passed an absolute filename --
-when this is the case, the shell/kernel passes the absolute pathname unaltered to
-B<perl>.
-
-=back
-
-=item C<$0> comes with a filename relative to the current directory
-
-This happens:
-
-=over
-
-=item *
-
-When the script was called with B<perl> I<relative_file_name> -- B<perl> will
-search the filename under the current directory;
-
-=item *
-
-When the script was called by the shebang and the shell/kernel was
-passed a relative filename -- when this is the case, the kernel/shell passes
-the relative filename to B<perl>, also unaltered.
-
-=back
-
-=back
-
-C<scriptname> follows symbolic links.
-
-And C<scriptname> has the B<lib> option, to prepend library paths relative
-to C<scriptname::mydir> to B<@INC>.
+None reported (so far).
 
 =head1 BUGS AND LIMITATIONS
 
@@ -229,19 +161,23 @@ Please report any bugs or feature requests to
 C<bug-scriptname@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-= head1 THANKS
 
-C<stevenl@cpan.org>, for pointing a silly mistake in my tests
+=head1 AUTHOR
 
-=head1 ALTERNATIVE LICENSE TERMS
+Humberto Massa  C<< <massa@cpan.org> >>
 
-Optionally, instead of using the Perl 5 programming language licensing
-terms, you are also autorized to redistribute and/or modify it under the
-terms of any of the following licenses, at your will: GNU LGPLv2, GNU
-LGPLv3, CC-LGPLv2, CC-By-SAv3.0.
+=head1 LICENCE AND COPYRIGHT
+
+Copyright (c) 2008, Humberto Massa C<< <massa@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. See L<perlartistic>.  Optionally,
+you can redistribute and/or modify it under the terms of any of the
+following licenses, at your will: GNU GPLv2, GNU GPLv3, CC-GPLv2,
+CC-SAv3.0.
 
 Please notice that the alternatives given in the previous paragraph apply
-B<only for this module> and other modules where explicitly stated.
+B<only for this module>.
 
 =head1 DISCLAIMER OF WARRANTY
 
@@ -265,17 +201,3 @@ RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
 FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
-
-=head1 AUTHOR
-
-Humberto Massa <massa@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Humberto Massa.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
